@@ -104,30 +104,30 @@ void usage(void)
 {
 	version();
 
-	printf("-t	show timestamp\n");
-	printf("-l	show link\n");
-	printf("-d	show description\n");
-	printf("-p	show publication date\n");
-	printf("-a	show author\n");
-	printf("-c	show comments\n");
+	printf("-t      show timestamp\n");
+	printf("-l      show link\n");
+	printf("-d      show description\n");
+	printf("-p      show publication date\n");
+	printf("-a      show author\n");
+	printf("-c      show comments\n");
 	printf("-N      do not show headings\n");
 	printf("-b x	limit description/comments to x bytes\n");
 	printf("-z      continue even if there are XML parser errors in the RSS feed\n");
 	printf("-Z x    add heading 'x'\n");
 	printf("-n x	initially show x items\n");
 	printf("-r            reverse output, so it looks more like an RSS feed\n");
-	printf("-H	strip HTML tags\n");
+	printf("-H      strip HTML tags\n");
 /*	printf("-o x    only show items newer then x[s/M/h/d/m/y]\n");	*/
 	printf("-A x    authenticate against webserver, x is in format username:password\n");
 	printf("-u url	URL of RSS feed to tail\n");
 	printf("-i x	check interval in seconds (default is 15min)\n");
 	printf("-x x	proxy server to use (host[:port])\n");
 	printf("-y x	proxy authorization (user:password)\n");
-	printf("-P	do not exit when an error occurs\n");
-	printf("-1	one shot\n");
-	printf("-v	be verbose (add more to be more verbose)\n");
-	printf("-V	show version and exit\n");
-	printf("-h	this help\n");
+	printf("-P      do not exit when an error occurs\n");
+	printf("-1      one shot\n");
+	printf("-v      be verbose (add more to be more verbose)\n");
+	printf("-V      show version and exit\n");
+	printf("-h      this help\n");
 }
 
 int main(int argc, char *argv[])
@@ -340,6 +340,8 @@ int main(int argc, char *argv[])
 	{
 		mrss_error_t err_read;
 		mrss_item_t *item_cur = NULL;
+		mrss_item_t *first_item[n_url];
+		mrss_item_t *tmp_first_item;
 		time_t cur_last_changed;
 		int n_shown = 0;
 
@@ -371,6 +373,11 @@ int main(int argc, char *argv[])
 				printf("Feed did not change since last check.\n");
 			goto goto_next_url;
 		}
+		else if (verbose > 2)
+		{
+			printf("Feed change detected, %s", ctime(&cur_last_changed));
+		}
+
 		last_changed = cur_last_changed;
 
 		if ((err_read = mrss_parse_url_with_options(url[cur_url], &data_cur[cur_url], &mot)) != MRSS_OK)
@@ -417,9 +424,11 @@ int main(int argc, char *argv[])
 			}
 		}
 
+		tmp_first_item = item_cur;
+
 		while(item_cur)
 		{
-			if ((data_prev[cur_url] && is_new_record(data_prev[cur_url] -> item, item_cur) != -1) ||
+			if ((data_prev[cur_url] && is_new_record(first_item[cur_url], item_cur) != -1) ||
 			    (!data_prev[cur_url]))
 			{
 #if 0
@@ -518,6 +527,7 @@ int main(int argc, char *argv[])
 
 		data_prev[cur_url] = data_cur[cur_url];
 		data_cur[cur_url] = NULL;
+		first_item[cur_url] = tmp_first_item;
 
 goto_next_url:
 		cur_url++;
